@@ -4,6 +4,7 @@ import importlib
 import json
 import os
 import pickle
+import shutil
 import typing
 from enum import Enum
 
@@ -32,12 +33,16 @@ class Storage(Enum):
     OTHER = 4
 
 
+class DriveCredentialsMode(Enum):
+    # Drive credentials mode enum
+    ADD = 1
+    DELETE = 2
+
+
 class save:
     """Save data, supports multiple systems.
 
     Supported Systems: [File, FTP, GOOGLE]
-    Partial Supported: []
-    Planning Support for: []
     """
 
     def __init__(self) -> None:
@@ -45,7 +50,11 @@ class save:
         self.encoding: Encoding = Enum(
             "Encoding", ["NONE", "JSON", "BINARY", "CRYPTOGRAPHY", "CSV"]
         )
-        self.storage: Storage = Enum("Storage", ["NORMAL", "FTP", "GOOGLE", "OTHER"])
+        self.storage: Storage = Enum(
+            "Storage", ["NORMAL", "FTP", "GOOGLE", "OTHER"])
+        self.DriveCredentialsEnum: DriveCredentialsMode = Enum(
+            "DriveCredentialsMode", ["ADD", "DELETE"]
+        )
         self.saveModules = {}
         self.settings = {
             "FTP": {"Name": "", "Password": ""},
@@ -69,7 +78,8 @@ class save:
             module = module[:-3]  # remove .py
             # Attempt to load the module
             try:
-                mdl = importlib.import_module(f"{SaveModules.__package__}.{module}")
+                mdl = importlib.import_module(
+                    f"{SaveModules.__package__}.{module}")
                 self.saveModules[module] = mdl.load()
             except (AttributeError, ModuleNotFoundError) as e:
                 Message.warn(
@@ -118,7 +128,8 @@ class save:
             )
 
             if data.get("Name") == "" or not correct:
-                data["Name"] = input("Please enter your username for the FTP server: ")
+                data["Name"] = input(
+                    "Please enter your username for the FTP server: ")
 
             data["Password"] = getpass.getpass(
                 "Please enter your password for the FTP server: "
@@ -160,7 +171,8 @@ class save:
         """
 
         key = self.enc.GetKey()  # get the byte version
-        self.settings["Passcode"] = key.decode("utf-8")  # store the byte as string
+        self.settings["Passcode"] = key.decode(
+            "utf-8")  # store the byte as string
 
         # save the data
         self.Save(
@@ -171,6 +183,45 @@ class save:
 
         return key
 
+    def DriveExists(self) -> bool:
+        """Checks if you already have credentials
+
+        Returns:
+            bool: If you have the credentials
+        """
+        return os.path.exists(f"{self.settings.get('SettingsSave')}/gCred.json")
+
+    def DriveCredentials(self, path: str, mode: DriveCredentialsMode):
+        """Copies, Delets the drive credential file.
+
+        Args:
+            path (str): The path of the `gCred.json` file
+            mode (DriveCredentialsMode): The mode (use DriveCredentialEnum)
+
+        Raises:
+            AttributeError: gCred.json wasn't found in target path
+            AttributeError: Mode specified was not a valid mode
+
+        Returns:
+            str: The result of the action
+        """
+        if not os.path.exists(f"{path}/gCred.json"):
+            raise AttributeError(
+                "Couldn't find `gCred.json` in the path specified!")
+
+        saveDir = os.path.dirname(self.settings.get("SettingsSave"))
+        if mode == self.DriveCredentialsEnum.ADD:
+            shutil.copy(path + "/gCred.json", saveDir + "/gCred.json")
+            return "Copied"
+
+        if mode == self.DriveCredentialsEnum.DELETE:
+            os.remove(saveDir + "/gCred.json")
+            return "Deleted"
+
+        raise AttributeError(
+            "Wrong mode specified! Please use self.DriveCredentialsEnum for the mode"
+        )
+
     def __CodeData(
         self, data: any, encoding: typing.List[Encoding], *, decode: bool = False
     ):
@@ -194,19 +245,21 @@ class save:
 
             if code.value == 2:
                 # simple json encode
-                result = json.dumps(result) if not decode else json.loads(result)
+                result = json.dumps(
+                    result) if not decode else json.loads(result)
                 continue
 
             if code.value == 3:
                 # simple byte encode
-                result = pickle.dumps(result) if not decode else pickle.loads(result)
+                result = pickle.dumps(
+                    result) if not decode else pickle.loads(result)
                 rBytes = True
 
             if code.value == 4:
                 Passcode = self.settings.get("Passcode")
 
                 if Passcode == "MGNiYzY2MTFmNTU0MGJkMDgwOWEzODhkYzk1YTYxNWI=":
-                    Message.warn("WARNING: DEFAULT PASSCODE IN USE!", colour="red")
+                    Message.warn("WARNING: DEFAULT PASSCODE IN USE!")
 
                 # Get passcode if not exists
                 if Passcode is None or Passcode == "":
@@ -281,7 +334,8 @@ class save:
 
         data, wByte = self.__CodeData(data, encoding)
 
-        module: SaveModules.template.SaveTemplate = self.saveModules.get(storage.name)
+        module: SaveModules.template.SaveTemplate = self.saveModules.get(
+            storage.name)
         return module.WriteData(data, path, wByte)
 
     def Read(self, path: str, encoding: typing.List = None) -> any:
@@ -295,7 +349,8 @@ class save:
             any: The data in the file
         """
         path, storage, encoding = self.__GetFileInformation(path, encoding)
-        module: SaveModules.template.SaveTemplate = self.saveModules.get(storage.name)
+        module: SaveModules.template.SaveTemplate = self.saveModules.get(
+            storage.name)
 
         rBytes = False
         for item in encoding:
@@ -321,7 +376,8 @@ class save:
         if storage is None:
             path, storage = self.__TranslateStorage(path)
 
-        module: SaveModules.template.SaveTemplate = self.saveModules.get(storage.name)
+        module: SaveModules.template.SaveTemplate = self.saveModules.get(
+            storage.name)
         module.credentials(self.settings)
         return module.MakeFolders(path)
 
@@ -332,7 +388,8 @@ class save:
             path (str): The path to remove that file
         """
         path, storage = self.__TranslateStorage(path)
-        module: SaveModules.template.SaveTemplate = self.saveModules.get(storage.name)
+        module: SaveModules.template.SaveTemplate = self.saveModules.get(
+            storage.name)
         module.credentials(self.settings)
         module.DeleteFile(path)
 
@@ -343,6 +400,7 @@ class save:
             path (str): The path to remove the folder
         """
         path, storage = self.__TranslateStorage(path)
-        module: SaveModules.template.SaveTemplate = self.saveModules.get(storage.name)
+        module: SaveModules.template.SaveTemplate = self.saveModules.get(
+            storage.name)
         module.credentials(self.settings)
         module.DeleteFolder(path)
